@@ -1,21 +1,27 @@
 __all__ = ['Pyomo2FuncDesigner']
 
-from coopr.pyomo.base import Constraint, Objective, Var, maximize
-from coopr.pyomo.base import expr, var
-from coopr.pyomo.base import param
-from coopr.pyomo.base import numvalue
-from coopr.pyomo.io.cpxlp import CPXLP_numeric_labeler
-from coopr.opt import SymbolMap
+import logging
 try:
     import FuncDesigner
     FD_available=True
 except ImportError:
     FD_available=False
 
-import logging
+from coopr.pyomo.base import SymbolMap, NumericLabeler
+from coopr.pyomo.base import Constraint, Objective, Var, active_subcomponents_data_generator 
+from coopr.pyomo.base import expr, var
+from coopr.pyomo.base import param
+from coopr.pyomo.base import numvalue
+
+try:
+    long
+    intlist = [int, float, long]
+except:
+    intlist = [int, float]
+
 logger = logging.getLogger('coopr.pyomo')
 
-labeler = CPXLP_numeric_labeler('x')
+labeler = NumericLabeler("x")
 
 if FD_available:
 
@@ -62,15 +68,15 @@ id_counter=0
 
 def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
     if isinstance(exp, expr._IntrinsicFunctionExpression):
-        if not exp.name in intrinsic_function_expressions:
-            logger.error("Unsupported intrinsic function (%s)", exp.name)
-            raise TypeError("FuncDesigner does not support '{0}' expressions".format(exp.name))
+        if not exp.cname() in intrinsic_function_expressions:
+            logger.error("Unsupported intrinsic function (%s)", exp.cname(True))
+            raise TypeError("FuncDesigner does not support '{0}' expressions".format(exp.cname(True)))
 
         args = []
         for child_exp in exp._args:
             args.append( Pyomo2FD_expression(child_exp, ipoint, vars, symbol_map) )
 
-        fn = intrinsic_function_expressions[exp.name]
+        fn = intrinsic_function_expressions[exp.cname()]
         return fn(*tuple(args))
 
     elif isinstance(exp, expr._SumExpression):
@@ -87,7 +93,7 @@ def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
         return FuncDesigner.sum([c*iargs.next() for c in exp._coef]) + exp._const
 
     elif isinstance(exp, expr._ProductExpression):
-        ans = exp.coef
+        ans = exp._coef
         for n in exp._numerator:
             ans *= Pyomo2FD_expression(n, ipoint, vars, symbol_map)
         for n in exp._denominator:
@@ -122,14 +128,14 @@ def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
     elif isinstance(exp,param._ParamData):
         return exp.value
 
-    elif type(exp) in [int, float, long]:
+    elif type(exp) in intlist:
         return exp
 
     elif isinstance(exp,numvalue.NumericConstant) or exp.is_fixed():
         return exp.value
 
     else:
-        raise ValueError, "Unsupported expression type in Pyomo2FD_expression: "+str(type(exp))
+        raise ValueError("Unsupported expression type in Pyomo2FD_expression: "+str(type(exp)))
 
 
 def Pyomo2FuncDesigner(instance):
@@ -145,48 +151,35 @@ def Pyomo2FuncDesigner(instance):
     _f_name = []
     _f = []
     _c = []
-    for c in instance.active_components():
-        if issubclass(c, Constraint):
-            cons = instance.active_components(c)
-            for con_set_name in cons:
-                con_set = cons[con_set_name]
-                # For each indexed constraint in the constraint set
-                for ndx in con_set._data:
-                    body = Pyomo2FD_expression(con_set._data[ndx].body, ipoint, vars, smap)
-                    if not con_set._data[ndx].lower is None:
-                        lower = Pyomo2FD_expression(con_set._data[ndx].lower, ipoint, vars, smap)
-                        _c.append( body > lower )
-                    if not con_set._data[ndx].upper is None:
-                        upper = Pyomo2FD_expression(con_set._data[ndx].upper, ipoint, vars, smap)
-                        _c.append( body < upper )
+    # BLOCK RECURSIVE WHEN JDS MAKES THAT CHANGE
+    for con in active_subcomponents_data_generator(instance,Constraint):
+        body = Pyomo2FD_expression(con.body, ipoint, vars, smap)
+        if not con.lower is None:
+            lower = Pyomo2FD_expression(con.lower, ipoint, vars, smap)
+            _c.append( body > lower )
+        if not con.upper is None:
+            upper = Pyomo2FD_expression(con.upper, ipoint, vars, smap)
+            _c.append( body < upper )
 
-        elif issubclass(c, Var):
-            _vars = instance.active_components(c)
-            for var_set_name in _vars:
-                var_set = _vars[var_set_name]
-                for ndx in var_set.keys():
-                    body = Pyomo2FD_expression(var_set[ndx], ipoint, vars, smap)
-                    if not var_set[ndx].lb is None:
-                        lower = Pyomo2FD_expression(var_set[ndx].lb, ipoint, vars, smap)
-                        _c.append( body > lower )
-                    if not var_set[ndx].ub is None:
-                        upper = Pyomo2FD_expression(var_set[ndx].ub, ipoint, vars, smap)
-                        _c.append( body < upper )
+    # BLOCK RECURSIVE WHEN JDS MAKES THAT CHANGE
+    for var in active_subcomponents_data_generator(instance,Var):
+        body = Pyomo2FD_expression(var, ipoint, vars, smap)
+        if not var.lb is None:
+            lower = Pyomo2FD_expression(var.lb, ipoint, vars, smap)
+            _c.append( body > lower )
+        if not var.ub is None:
+            upper = Pyomo2FD_expression(var.ub, ipoint, vars, smap)
+            _c.append( body < upper )
 
-        elif issubclass(c, Objective):
-            objs = instance.active_components(c)
-            for obj_set_name in objs:
-                obj_set = objs[obj_set_name]
-                sense = obj_set.sense
-                # For each indexed objective in the objective set
-                for ndx in obj_set._data:
-                    nobj += 1
-                    if sense == maximize:
-                        _f.append( - Pyomo2FD_expression(obj_set._data[ndx].expr, ipoint, vars, smap) )
-                    else:
-                        _f.append( Pyomo2FD_expression(obj_set._data[ndx].expr, ipoint, vars, smap) )
-                    _f_name.append( obj_set._data[ndx].name )
-                    smap.getSymbol(obj_set._data[ndx], lambda obj,x: x, obj_set._data[ndx].name)
+
+    for obj in active_subcomponents_data_generator(instance,Objective):
+        nobj += 1
+        if obj.is_minimizing():
+            _f.append( Pyomo2FD_expression(obj.expr, ipoint, vars, smap) )
+        else:
+            _f.append( - Pyomo2FD_expression(obj.expr, ipoint, vars, smap) )
+        _f_name.append( obj.cname(True) )
+        smap.getSymbol(obj, lambda objective: objective.cname(True))
 
     # TODO - use 0.0 for default values???
     # TODO - create results map
@@ -197,9 +190,5 @@ def Pyomo2FuncDesigner(instance):
     S.constraints.update(_c)
     S.initial_point = ipoint
     S.sense = sense
-    #print ipoint
-    #print dir(S)
-    #print S.nlpSolvers
-    #print S.constraints
     return S
 
