@@ -1,10 +1,9 @@
 from pyutilib.misc import Options
 import pyutilib.th as unittest
 from coopr.pyomo import *
-from func_designer import Pyomo2FuncDesigner
-
+from coopr.openopt.func_designer import Pyomo2FuncDesigner
 try:
-    import FuncDesigner
+    import coopr.openopt.FuncDesigner
     FD_available=True
 except:
     FD_available=False
@@ -32,7 +31,6 @@ class Tests(unittest.TestCase):
 @unittest.nottest
 def expr_test(self, name):
     options = self.get_options(name)
-    #print name, options.fn.func_name, options.x
     self.model.x.value = options.x
     if name == 'pow':
         self.model.f = Objective(expr=options.fn(self.model.x, 2))
